#!/usr/bin/perl

use strict;
use warnings;

use Test::More tests => 1;

BEGIN {
    use_ok('Moose::Policy');           
}

{
    package My::Moose::Meta::Attribute;
    use Moose;
    
    extends 'Moose::Meta::Attribute';
    
    sub _process_options {
        my ($class, $name, $options) = @_;
    	if (exists $options->{is}) {
    		if ($options->{is} eq 'ro') {
    			$options->{reader} = 'get_' . $name;
    		}
    		elsif ($options->{is} eq 'rw') {
                $options->{reader} = 'get_' . $name;							
                $options->{writer} = 'set_' . $name;    			
    		}
    		delete $options->{is};
    	}
    	
        $class->SUPER::_process_options($name, $options);
    }
}

{
    package My::Moose::Policy;
    use constant attribute_metaclass => 'My::Moose::Meta::Attribute';
}

{
    package Foo;
    
    use Moose::Policy 'My::Moose::Policy';
    use Moose;
    
    has 'bar' => (default => 'Foo::bar');
}

isa_ok(Foo->meta, 'Moose::Meta::Class');
is(Foo->meta->attribute_metaclass, 'My::Moose::Meta::Attribute', '... got our custom attr metaclass');

isa_ok()

my $foo = Foo->new;
isa_ok($foo, 'Foo');

can_ok($foo, 'get_bar');
can_ok($foo, 'set_bar');

is($foo->get_bar, 'Foo::bar', '... got the right default value');





